OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Detyra",
    "Important" : "E rëndësishme",
    "Today" : "Sot",
    "Week" : "Javë",
    "All" : "Krejt",
    "Current" : "E tanishmja",
    "Completed" : "Të plotësuara",
    "Delete" : "Fshije",
    "Cancel" : "Anuloje",
    "Change sort order" : "Ndryshoni rend renditjeje",
    "Default" : "Parazgjedhje",
    "Due date" : "Datë përfundimi",
    "Start date" : "Datë nisjeje",
    "Priority" : "Përparësi",
    "Manually" : "Dorazi",
    "Alphabetically" : "Alfabetikisht",
    "Task is completed" : "Detyra është e plotësuar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Punë e Plotësuar","%n Punë të Plotësuara"],
    "Tomorrow" : "Nesër",
    "Set start date" : "Caktoni datë fillimi",
    "Set due date" : "Caktoni datë mbarimi",
    "All day" : "Gjithë ditën",
    "Task not found!" : "S’u gjet punë!",
    "Edit" : "Përpunoni",
    "Download" : "Shkarkoje",
    "Save" : "Ruaje",
    "New List" : "Listë e Re",
    "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
    "Settings" : "Rregullime",
    "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
    "Hidden" : "I padukshëm",
    "Visible" : "I dukshëm",
    "Automatic" : "Automatike"
},
"nplurals=2; plural=(n != 1);");
